@@ -80,10 +80,12 @@
 #' @param clip Lower and upper limits for clipping confidence intervals to arrows
 #' @param xlab x-axis label
 #' @param zero x-axis coordinate for zero line. If you provide a vector of length 2 it
-#'   will print a rectangle instead of just a line
+#'   will print a rectangle instead of just a line.
 #' @param graphwidth Width of confidence interval graph, see \code{\link[grid]{unit}} for
 #'   details on how to utilize mm etc. The default is \code{auto}, that is it uses up whatever
 #'   space that is left after adjusting for text size and legend
+#' @param colgap Sets the gap between columns, defaults to 6 mm but for relative widths.
+#'   Note that the value should be in \code{\link[grid]{unit}(,"npc")}.
 #' @param lineheight Height of the graph. By default this is \code{auto} and adjustes to the
 #'   space that is left after adjusting for x-axis size and legend. Sometimes
 #'   it might be desireable to set the line height to a certain height, for
@@ -138,8 +140,8 @@
 #' @param legend Legend corresponding to the number of bars
 #' @param legend_args The legend arguments as returned by the \code{\link{fpLegend}} function.
 #' @param new_page If you want the plot to appear on a new blank page then set this to \code{TRUE}, by
-#'  default it is \code{FALSE}. If you want to change this behavior for all plots then
-#'  set the \code{options(forestplot_new_page = TRUE)}
+#'  default it is \code{TRUE}. If you want to change this behavior for all plots then
+#'  set the \code{options(forestplot_new_page = FALSE)}
 #' @param fn.ci_norm You can specify exactly how the line with the box is
 #'  drawn for the normal (i.e. non-summary) confidence interval by changing this
 #'  parameter to your own function or some of the alternatives provided in the package.
@@ -154,6 +156,7 @@
 #'  \code{fn.ci_sum} arguments
 #'
 #' @import grid
+#' @importFrom grDevices dev.cur
 #'
 #' @author Max Gordon, Thomas Lumley
 #'
@@ -170,6 +173,7 @@ forestplot <- function (labeltext,
                         xlab                 = "",
                         zero                 = ifelse(xlog, 1, 0),
                         graphwidth           = "auto",
+                        colgap,
                         lineheight           = "auto",
                         line.margin,
                         col                  = fpColors(),
@@ -189,48 +193,24 @@ forestplot <- function (labeltext,
                         title,
                         legend,
                         legend_args          = fpLegend(),
-                        new_page             = getOption("forestplot_new_page", FALSE),
+                        new_page             = getOption("forestplot_new_page", TRUE),
                         fn.ci_norm           = fpDrawNormalCI,
                         fn.ci_sum            = fpDrawSummaryCI,
                         fn.legend,
                         ...)
 {
-  # Warnings due to interface changes in 1.0
-  dot_args <- list(...)
-  if (any(grepl("^legend\\.", names(dot_args)))){
-    l_args <- names(dot_args)[grep("^legend\\.", names(dot_args))]
-    warning("The legend arguments have been grouped into legend_args, see documentation.",
-            " You have provided the following legend arguments: '", paste(l_args, collapse="', '"), "'",
-            " these will overwrite any arguments generated by the real legend_args",
-            "  in order to maintain backwards compatibility")
-    for (n in l_args){
-      short_name <- gsub("^legend\\.", "", n)
-      legend_args[[short_name]] <- dot_args[[n]]
-      dot_args[[n]] <- NULL
-    }
-  }
-  API_changes <-
-    c(confintNormalFn = "fn.ci_norm",
-      confintSummaryFn = "fn.ci_sum",
-      legendMarkerFn = "fn.legend",
-      main = "title")
-  fenv <- environment()
-  for (i in 1:length(API_changes)){
-    old_name <- names(API_changes)[i]
-    new_name <- API_changes[i]
-    if (old_name %in% names(dot_args)){
-      if (class(fenv[[new_name]]) == "name"){
-        fenv[[new_name]] <- dot_args[[old_name]]
-        dot_args[[old_name]] <- NULL
-        warning("Deprecated: '", old_name, "'",
-                " argument is now '", new_name ,"'",
-                " as of ver. 1.0")
-      }else{
-        stop("You have set both the old parameter name: '", old_name, "'",
-             " and the new parameter name: '", new_name, "'.")
-      }
-    }
+  if (missing(colgap)){
+    colgap <- convertUnit(unit(6, "mm"), "npc", valueOnly=TRUE)
+    if (colgap < .1)
+      colgap <- unit(.05, "npc")
+    else
+      colgap <- unit(colgap, "npc")
+  }else if(!grid::is.unit(colgap)){
+    colgap <- as.numeric(colgap)
+    if (is.na(colgap))
+      stop("Invalid colgap argument")
   }
+  colgap <- convertUnit(colgap, "mm")
 
   if (!inherits(txt_gp, "fpTxtGp"))
     stop("The txt_gp argument must come from a call to the fpTxtGp() function")
@@ -352,26 +332,22 @@ forestplot <- function (labeltext,
   if (is.data.frame(upper))
     upper <- as.matrix(upper)
 
+  # Instantiate a new page - forced if no device exists
+  if (new_page || dev.cur() == 1) grid.newpage()
+
   # Save the original values since the function due to it's inheritance
   # from the original forestplot needs some changing to the parameters
   if (xlog){
     if (any(mean < 0, na.rm = TRUE) ||
-          any(lower < 0, na.rm = TRUE) ||
-          any(upper < 0, na.rm = TRUE) ||
-          zero <= 0 ||
-          (!missing(clip) && any(clip <= 0, na.rm = TRUE))){
-      warning("The values should be provided as exponentials when using the log scale.",
-              " This is an intentional break with the original forestplot function in order",
-              " to simplify other arguments such as ticks, clips, and more. The function has",
-              " converted the values using exp() but it is recommended that this is done prior",
-              " to calling the function in order to avoid any unnecessary errors.")
-      if (zero <= 0)
-        zero = exp(zero)
-      if (any(clip) < 0)
-        clip = exp(clip)
-      mean <- exp(mean)
-      lower <- exp(lower)
-      upper <- exp(upper)
+        any(lower < 0, na.rm = TRUE) ||
+        any(upper < 0, na.rm = TRUE) ||
+        zero <= 0 ||
+        (!missing(clip) && any(clip <= 0, na.rm = TRUE)) ||
+        (!missing(grid) && any(grid <= 0, na.rm = TRUE))){
+      stop("All argument values (mean, lower, upper, zero, grid and clip)",
+           " should be provided as exponentials when using the log scale.",
+           " This is an intentional break with the original forestplot function in order",
+           " to simplify other arguments such as ticks, clips, and more.")
     }
 
     # Change all the values along the log scale
@@ -500,16 +476,6 @@ forestplot <- function (labeltext,
                           txt_gp = txt_gp,
                           col = col)
 
-  # Set the gap between columns, I set it to
-  # 6 mm but for relative widths we switch it
-  # to npc that adapts to the window size
-  colgap <- convertUnit(unit(6, "mm"), "npc", valueOnly=TRUE)
-  if (colgap < .1)
-    colgap <- unit(.05, "npc")
-  else
-    colgap <- unit(colgap, "npc")
-  colgap <- convertUnit(colgap, "mm")
-
   # There is always at least one column so grab the widest one
   # and have that as the base for the column widths
   colwidths <- unit.c(prFpFindWidestGrob(labels[[1]]))
@@ -532,7 +498,8 @@ forestplot <- function (labeltext,
                                         lwd.xaxis = lwd.xaxis,
                                         txt_gp = txt_gp,
                                         col = col,
-                                        clip = clip, zero = zero,
+                                        clip = clip,
+                                        zero = zero,
                                         x_range=prFpXrange(upper = upper,
                                                            lower = lower,
                                                            clip = clip,
@@ -543,10 +510,9 @@ forestplot <- function (labeltext,
                                         graph.pos = graph.pos)
   clip <- axisList$clip
 
-  ###################
-  # Create the plot #
-  ###################
-  if (new_page) grid.newpage()
+  ##################
+  # Build the plot #
+  ##################
 
   # Adjust for the margins and the x-axis + label
   marList <- list()
@@ -670,7 +636,7 @@ forestplot <- function (labeltext,
     # If graph width is not provided as a unit the autosize it to the
     # rest of the space available
     npc_colwidths <- convertUnit(unit.c(colwidths, colgap), "npc", valueOnly=TRUE)
-    graphwidth <- unit(1 - sum(npc_colwidths), "npc")
+    graphwidth <- unit(max(.05, 1 - sum(npc_colwidths)), "npc")
   }else if(!is.unit(graphwidth)){
     stop("You have to provide graph width either as a unit() object or as 'auto'.",
       " Auto sizes the graph to maximally use the available space.",
